@@ -16,7 +16,7 @@ glm_model <- function(family, link, Mlist, K, ...){
                     paste0("dgamma(shape_", y_name, "[j], rate_", y_name, "[j])")
                   },
                   "poisson" = function(y_name) {
-                    paste0("dpois(mu_", y_name, "[j])")
+                    paste0("dpois(max(1e-10, mu_", y_name, "[j]))")
                   }
   )
 
@@ -39,7 +39,10 @@ glm_model <- function(family, link, Mlist, K, ...){
                     "log"      = function(x) paste0("log(", x, ")"),
                     "cloglog"  = function(x) paste0("cloglog(", x, ")"),
                     # "sqrt": JAGS does not have this link function
-                    "inverse"  = function(x) paste0("1/", x)
+                    # "inverse"  = function(x) paste0("1/", x)
+                    "inverse"  = function(x)
+                      paste0(x, " <- 1/max(1e-10, inv_", x, ")", "\n",
+                             tab(4), "inv_", x)
   )
 
   paste_Xic <- if (!is.null(Mlist$Xic)) {
