@@ -11,13 +11,18 @@ get_subset <- function(object, subset, keep_aux = FALSE, warn = TRUE, mess = TRU
   if (!length(subset) == 0 && is.null(as.list(subset)$analysis_main))
     subset$analysis_main <- FALSE
 
-  s <- do.call(get_params, c(object, object$Mlist, subset, mess = mess))
+
+  Mlist_new <- object$Mlist
+  Mlist_new$ppc <- as.list(subset)$ppc
+
+  s <- do.call(get_params, c(object, Mlist_new, subset, mess = mess))
 
   repl <- sapply(s, function(r) {
     if (grepl("^beta$", r)) {
       get_coef_names(object$Mlist, object$K)[, 2]
-    } else if (!r %in% colnames(object$MCMC[[1]]) & any(grepl(r, colnames(object$MCMC[[1]])))) {
-      grep(paste0(r, "\\[[[:digit:]]+\\]"), colnames(object$MCMC[[1]]), value = TRUE)
+    } else if (!r %in% colnames(object$MCMC[[1]]) & any(grepl(paste0('^', r, '\\['), colnames(object$MCMC[[1]])))) {
+      # grep(paste0(r, "\\[[[:digit:]]+\\]"), colnames(object$MCMC[[1]]), value = TRUE)
+      grep(paste0("^", r, "\\["), colnames(object$MCMC[[1]]), value = TRUE)
     }
   }, simplify = FALSE)
 
