@@ -17,23 +17,23 @@ get_RNG <- function(seed, n.chains) {
 
 
 
-run_jags <- function(i, data_list, modelfile, n.adapt, n.iter, var.names) {
+run_jags <- function(i, data_list, modelfile, n.adapt, n.iter, var.names, thin) {
 
   adapt <- rjags::jags.model(file = modelfile, n.adapt = n.adapt,
                              n.chains = 1, inits = i, data = data_list,
                              quiet = TRUE)
 
   mcmc <- rjags::coda.samples(adapt, n.iter = n.iter, variable.names = var.names,
-                              progress.bar = 'none')
+                              thin = thin, progress.bar = 'none')
 
   return(list(adapt = adapt, mcmc = mcmc))
 }
 
 
 
-run_samples <- function(adapt, n.iter, var.names) {
+run_samples <- function(adapt, n.iter, var.names, thin) {
   adapt$recompile()
   mcmc <- rjags::coda.samples(adapt, n.iter = n.iter, variable.names = var.names,
-                              progress.bar = 'none')
+                              progress.bar = 'none', thin = thin)
   return(list(adapt = adapt, mcmc = mcmc))
 }
